const path = require('path');
const HtmlWebpackPlugin = require('html-webpack-plugin');
const MiniCssExtractPlugin = require('mini-css-extract-plugin');
const webpack = require('webpack')
module.exports = {
    entry: {
        app: './src/index.js'
    },
    devtool: 'inline-source-map',
    mode: 'development',
    devServer: {
        // contentBase: './dist',
        static:{
            directory: path.join(__dirname, 'public'),
        },
        port: 3000,
    },
    plugins: [
        new HtmlWebpackPlugin({
            title: 'Development',
            template: './public/index.html'
        }),
        new MiniCssExtractPlugin({
            filename: 'static/[name]-[contenthash:8].css'
          }),
    ],
    output: {
        filename: '[name].bundle.js',
        path: path.resolve(__dirname, 'dist')
    },
    module: {
        rules: [
            {
                test: /\.(js|jsx)$/,
                use: {
                    loader: "babel-loader"
                }
            },
            {
                test: /\.html$/,
                exclude: /(public)/,
                use: {
                    loader: "html-loader"
                }
            },
            {
                test: /\.css$/,
                use: ['style-loader', 'css-loader']
            },
            {
                test: /\.(png|jpg|svg)$/,
                exclude: /(node_modules)/,
                use: [{
                    loader: "url-loader",
                    options: {
                        limit: 1024,
                        name: 'static/images/[name].[hash:8].[ext]'
                    }
                }]
            },
            { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, loader: "file-loader" },
            { test: /\.(woff|woff2)$/, loader:"url-loader" },
            { test: /\.ttf(\?v=\d+\.\d+\.\d+)?$/, loader: "url-loader" },
            { test: /\.svg(\?v=\d+\.\d+\.\d+)?$/, loader: "url-loader" }
        ]
    }
};